==> retext_2.1.6.orig.tar.gz: locale/retext_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0" language="de" sourcelanguage="en_US">
<context>
    <name>LogPassDialog</name>
    <message>
        <location filename="retext.py" line="146"/>
        <source>Enter your Google account data</source>
        <translation>Daten des Googlekontos eingeben</translation>
    </message>
    <message>
        <location filename="retext.py" line="155"/>
        <source>Username</source>
        <translation>Benutzername</translation>
    </message>
    <message>
        <location filename="retext.py" line="156"/>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
</context>
<context>
    <name>ReTextWindow</name>
    <message>
        <location filename="retext.py" line="216"/>
        <source>File toolbar</source>
        <translation>Datei-Werkzeugleiste</translation>
    </message>
    <message>
        <location filename="retext.py" line="218"/>
        <source>Edit toolbar</source>
        <translation>Werkzeugleiste bearbeiten</translation>
    </message>
    <message>
        <location filename="retext.py" line="220"/>
        <source>Search toolbar</source>
        <translation>Such-Werkzeugleiste</translation>
    </message>
    <message>
        <location filename="retext.py" line="222"/>
        <source>New</source>
        <translation>Neu</translation>
    </message>
    <message>
        <location filename="retext.py" line="226"/>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <location filename="retext.py" line="230"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="retext.py" line="235"/>
        <source>Save as</source>
        <translation>Speichern als</translation>
    </message>
    <message>
        <location filename="retext.py" line="238"/>
        <source>Print</source>
        <translation>Drucken</translation>
    </message>
    <message>
        <location filename="retext.py" line="242"/>
        <source>Print preview</source>
        <translation>Druckvorschau</translation>
    </message>
    <message>
        <location filename="retext.py" line="244"/>
        <source>View HTML code</source>
        <translation>HTML-Code anzeigen</translation>
    </message>
    <message>
        <location filename="retext.py" line="246"/>
        <source>Change default font</source>
        <translation>Standardschriftart ändern</translation>
    </message>
    <message>
        <location filename="retext.py" line="248"/>
        <source>Find text</source>
        <translation>Suche</translation>
    </message>
    <message>
        <location filename="retext.py" line="253"/>
        <source>Preview</source>
        <translation>Vorschau</translation>
    </message>
    <message>
        <location filename="retext.py" line="265"/>
        <source>Live preview</source>
        <translation>Live-Vorschau</translation>
    </message>
    <message>
        <location filename="retext.py" line="269"/>
        <source>Fullscreen mode</source>
        <translation>Vollbildmodus</translation>
    </message>
    <message>
        <location filename="retext.py" line="281"/>
        <source>Other formats</source>
        <translation>Andere Formate</translation>
    </message>
    <message>
        <location filename="retext.py" line="287"/>
        <source>Quit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <location filename="retext.py" line="291"/>
        <source>Undo</source>
        <translation>Rückgängig</translation>
    </message>
    <message>
        <location filename="retext.py" line="293"/>
        <source>Redo</source>
        <translation>Wiederholen</translation>
    </message>
    <message>
        <location filename="retext.py" line="297"/>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <location filename="retext.py" line="300"/>
        <source>Cut</source>
        <translation>Ausschneiden</translation>
    </message>
    <message>
        <location filename="retext.py" line="303"/>
        <source>Paste</source>
        <translation>Einfügen</translation>
    </message>
    <message>
        <location filename="retext.py" line="319"/>
        <source>Enable</source>
        <translation>Einschalten</translation>
    </message>
    <message>
        <location filename="retext.py" line="321"/>
        <source>Set locale</source>
        <translation>Spracheinstellung</translation>
    </message>
    <message>
        <location filename="retext.py" line="332"/>
        <source>Plain text</source>
        <translation>Klartext</translation>
    </message>
    <message>
        <location filename="retext.py" line="338"/>
        <source>Generate webpages</source>
        <translation>Webseite generieren</translation>
    </message>
    <message>
        <location filename="retext.py" line="340"/>
        <source>Show</source>
        <translation>Anzeigen</translation>
    </message>
    <message>
        <location filename="retext.py" line="342"/>
        <source>Next</source>
        <translation>Weiter</translation>
    </message>
    <message>
        <location filename="retext.py" line="344"/>
        <source>Previous</source>
        <translation>Zurück</translation>
    </message>
    <message>
        <location filename="retext.py" line="348"/>
        <source>Get help online</source>
        <translation>Online Hilfe bekommen</translation>
    </message>
    <message>
        <location filename="retext.py" line="1134"/>
        <source>About %1</source>
        <translation>Über %1</translation>
    </message>
    <message>
        <location filename="retext.py" line="353"/>
        <source>About Qt</source>
        <translation>Über Qt</translation>
    </message>
    <message>
        <location filename="retext.py" line="374"/>
        <source>Save to Google Docs</source>
        <translation>In Google Docs speichern</translation>
    </message>
    <message>
        <location filename="retext.py" line="380"/>
        <source>Tags</source>
        <translation>Stichworte</translation>
    </message>
    <message>
        <location filename="retext.py" line="384"/>
        <source>Symbols</source>
        <translation>Symbole</translation>
    </message>
    <message>
        <location filename="retext.py" line="398"/>
        <source>File</source>
        <translation>Datei</translation>
    </message>
    <message>
        <location filename="retext.py" line="399"/>
        <source>Edit</source>
        <translation>Bearbeiten</translation>
    </message>
    <message>
        <location filename="retext.py" line="400"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <location filename="retext.py" line="764"/>
        <source>Open recent</source>
        <translation>Zuletzt geöffnet</translation>
    </message>
    <message>
        <location filename="retext.py" line="404"/>
        <source>Directory</source>
        <translation>Verzeichnis</translation>
    </message>
    <message>
        <location filename="retext.py" line="412"/>
        <source>Export</source>
        <translation>Exportieren</translation>
    </message>
    <message>
        <location filename="retext.py" line="433"/>
        <source>Spell check</source>
        <translation>Rechtschreibprüfung</translation>
    </message>
    <message>
        <location filename="retext.py" line="441"/>
        <source>Default editing mode</source>
        <translation>Standard-Bearbeitungsmodus</translation>
    </message>
    <message>
        <location filename="retext.py" line="476"/>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <location filename="retext.py" line="480"/>
        <source>Case sensitively</source>
        <translation>Groß-/Kleinschreibung</translation>
    </message>
    <message>
        <location filename="retext.py" line="1122"/>
        <source>New document</source>
        <translation>Neues Dokument</translation>
    </message>
    <message>
        <location filename="retext.py" line="497"/>
        <source>You have neither Markdown nor Docutils modules installed!</source>
        <translation>Es sind weder Markdown- noch Docutils-Module installiert!</translation>
    </message>
    <message>
        <location filename="retext.py" line="497"/>
        <source>Only HTML formatting will be available.</source>
        <translation>Es wird nur HTML-Formatierung verfügbar sein.</translation>
    </message>
    <message>
        <location filename="retext.py" line="646"/>
        <source>Enter locale name (example: en_US)</source>
        <translation>Spracheinstellung eingeben (zum Beispiel: de_DE)</translation>
    </message>
    <message>
        <location filename="retext.py" line="735"/>
        <source>Please, save the file somewhere.</source>
        <translation>Bitte die Datei irgendwo speichern.</translation>
    </message>
    <message>
        <location filename="retext.py" line="722"/>
        <source>Webpages saved in &lt;code&gt;html&lt;/code&gt; directory.</source>
        <translation>Webseiten gespeichert im Verzeichnis &lt;code&gt;html&lt;/code&gt;.</translation>
    </message>
    <message>
        <location filename="retext.py" line="724"/>
        <source>Show directory</source>
        <translation>Verzeichnis anzeigen</translation>
    </message>
    <message>
        <location filename="retext.py" line="729"/>
        <source>Webpages generator is not installed!</source>
        <translation>Webseiten-Generator ist nicht installiert!</translation>
    </message>
    <message>
        <location filename="retext.py" line="769"/>
        <source>Select one or several files to open</source>
        <translation>Ein oder mehrere Dateien zum Öffnen auswählen</translation>
    </message>
    <message>
        <location filename="retext.py" line="769"/>
        <source>Supported files</source>
        <translation>Unterstützte Dateien</translation>
    </message>
    <message>
        <location filename="retext.py" line="769"/>
        <source>All files (*)</source>
        <translation>Alle Dateien (*)</translation>
    </message>
    <message>
        <location filename="retext.py" line="824"/>
        <source>Plain text (*.txt)</source>
        <translation>Klartext (*.txt)</translation>
    </message>
    <message>
        <location filename="retext.py" line="827"/>
        <source>ReStructuredText files</source>
        <translation>ReStructuredText-Dateien</translation>
    </message>
    <message>
        <location filename="retext.py" line="830"/>
        <source>HTML files</source>
        <translation>HTML-Dateien</translation>
    </message>
    <message>
        <location filename="retext.py" line="833"/>
        <source>Markdown files</source>
        <translation>Markdown-Dateien</translation>
    </message>
    <message>
        <location filename="retext.py" line="913"/>
        <source>Save file</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="retext.py" line="847"/>
        <source>Cannot save to file because it is read-only!</source>
        <translation>Kann nicht speichern, Datei ist schreibgeschützt.</translation>
    </message>
    <message>
        <location filename="retext.py" line="904"/>
        <source>Export document to ODT</source>
        <translation>Dokument in ODT exportieren</translation>
    </message>
    <message>
        <location filename="retext.py" line="904"/>
        <source>OpenDocument text files (*.odt)</source>
        <translation>OpenDocument-Dateien (*.odt)</translation>
    </message>
    <message>
        <location filename="retext.py" line="913"/>
        <source>HTML files (*.html *.htm)</source>
        <translation>HTML-Dateien  (*.html, *.htm)</translation>
    </message>
    <message>
        <location filename="retext.py" line="929"/>
        <source>Export document to PDF</source>
        <translation>Dokument in PDF exportieren</translation>
    </message>
    <message>
        <location filename="retext.py" line="929"/>
        <source>PDF files (*.pdf)</source>
        <translation>PDF-Dateien (*.pdf)</translation>
    </message>
    <message>
        <location filename="retext.py" line="946"/>
        <source>Print document</source>
        <translation>Dokument drucken</translation>
    </message>
    <message>
        <location filename="retext.py" line="968"/>
        <source>Export document</source>
        <translation>Dokument exportieren</translation>
    </message>
    <message>
        <location filename="retext.py" line="963"/>
        <source>This function is not available in Plain text mode!</source>
        <translation>Diese Funktion ist im Klartext-Modus nicht verfügbar!</translation>
    </message>
    <message>
        <location filename="retext.py" line="966"/>
        <source>Select type</source>
        <translation>Typ auswählen</translation>
    </message>
    <message>
        <location filename="retext.py" line="1035"/>
        <source>Incorrect user name or password!</source>
        <translation>Benutzername oder Passwort fehlerhaft!</translation>
    </message>
    <message>
        <location filename="retext.py" line="1038"/>
        <source>Authentification failed, please check your internet connection!</source>
        <translation>Authentifikation fehlgeschlagen, bitte Internetverbindung überprüfen!</translation>
    </message>
    <message>
        <location filename="retext.py" line="1100"/>
        <source>The document has been modified.
Do you want to save your changes?</source>
        <translation>Das Dokument wurde verändert.⏎
Sollen die Änderungen gespeichert werden?</translation>
    </message>
    <message>
        <location filename="retext.py" line="1125"/>
        <source>HTML code</source>
        <translation>HTML-Code</translation>
    </message>
    <message>
        <location filename="retext.py" line="1134"/>
        <source>Simple but powerful editor for Markdown and ReStructuredText</source>
        <translation>Einfacher aber mächtiger Editor für Markdown and ReStructuredText</translation>
    </message>
    <message>
        <location filename="retext.py" line="1134"/>
        <source>Author: Dmitry Shachnev, 2011</source>
        <translation>Autor: Dmitry Shachnev, 2011</translation>
    </message>
    <message>
        <location filename="retext.py" line="1134"/>
        <source>Website</source>
        <translation>Webseite</translation>
    </message>
    <message>
        <location filename="retext.py" line="1134"/>
        <source>Markdown syntax</source>
        <translation>Markdown-Syntax</translation>
    </message>
    <message>
        <location filename="retext.py" line="1134"/>
        <source>ReST syntax</source>
        <translation>ReST-Syntax</translation>
    </message>
    <message>
        <location filename="retext.py" line="1187"/>
        <source>Could not parse file contents, check if you have the necessary module installed!</source>
        <translation>Dateiinhalt konnte nicht geparst werden. Überprüfen Sie, ob die notwendigen Module installiert sind!</translation>
    </message>
</context>
</TS>

==> retext_3.1.0.orig.tar.gz: locale/retext_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0" language="de" sourcelanguage="en_US">
<context>
    <name>LogPassDialog</name>
    <message>
        <location filename="retext.py" line="208"/>
        <source>Enter your Google account data</source>
        <translation>Daten des Googlekontos eingeben</translation>
    </message>
    <message>
        <location filename="retext.py" line="217"/>
        <source>Username</source>
        <translation>Benutzername</translation>
    </message>
    <message>
        <location filename="retext.py" line="218"/>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
</context>
<context>
    <name>ReTextWindow</name>
    <message>
        <location filename="retext.py" line="287"/>
        <source>File toolbar</source>
        <translation>Datei-Werkzeugleiste</translation>
    </message>
    <message>
        <location filename="retext.py" line="289"/>
        <source>Edit toolbar</source>
        <translation>Werkzeugleiste bearbeiten</translation>
    </message>
    <message>
        <location filename="retext.py" line="291"/>
        <source>Search toolbar</source>
        <translation>Such-Werkzeugleiste</translation>
    </message>
    <message>
        <location filename="retext.py" line="293"/>
        <source>New</source>
        <translation>Neu</translation>
    </message>
    <message>
        <location filename="retext.py" line="295"/>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <location filename="retext.py" line="297"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="retext.py" line="300"/>
        <source>Save as</source>
        <translation>Speichern als</translation>
    </message>
    <message>
        <location filename="retext.py" line="302"/>
        <source>Print</source>
        <translation>Drucken</translation>
    </message>
    <message>
        <location filename="retext.py" line="304"/>
        <source>Print preview</source>
        <translation>Druckvorschau</translation>
    </message>
    <message>
        <location filename="retext.py" line="306"/>
        <source>View HTML code</source>
        <translation>HTML-Code anzeigen</translation>
    </message>
    <message>
        <location filename="retext.py" line="307"/>
        <source>Change default font</source>
        <translation>Standardschriftart ändern</translation>
    </message>
    <message>
        <location filename="retext.py" line="308"/>
        <source>Find text</source>
        <translation>Suche</translation>
    </message>
    <message>
        <location filename="retext.py" line="312"/>
        <source>Preview</source>
        <translation>Vorschau</translation>
    </message>
    <message>
        <location filename="retext.py" line="321"/>
        <source>Live preview</source>
        <translation>Live-Vorschau</translation>
    </message>
    <message>
        <location filename="retext.py" line="323"/>
        <source>Fullscreen mode</source>
        <translation>Vollbildmodus</translation>
    </message>
    <message>
        <location filename="retext.py" line="329"/>
        <source>Quit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <location filename="retext.py" line="332"/>
        <source>Undo</source>
        <translation>Rückgängig</translation>
    </message>
    <message>
        <location filename="retext.py" line="334"/>
        <source>Redo</source>
        <translation>Wiederholen</translation>
    </message>
    <message>
        <location filename="retext.py" line="336"/>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <location filename="retext.py" line="338"/>
        <source>Cut</source>
        <translation>Ausschneiden</translation>
    </message>
    <message>
        <location filename="retext.py" line="340"/>
        <source>Paste</source>
        <translation>Einfügen</translation>
    </message>
    <message>
        <location filename="retext.py" line="349"/>
        <source>Enable</source>
        <translation>Einschalten</translation>
    </message>
    <message>
        <location filename="retext.py" line="350"/>
        <source>Set locale</source>
        <translation>Spracheinstellung</translation>
    </message>
    <message>
        <location filename="retext.py" line="351"/>
        <source>Plain text</source>
        <translation>Klartext</translation>
    </message>
    <message>
        <location filename="retext.py" line="353"/>
        <source>Use WebKit renderer</source>
        <translation>WebKit-Renderer benutzen</translation>
    </message>
    <message>
        <location filename="retext.py" line="360"/>
        <source>Generate webpages</source>
        <translation>Webseite generieren</translation>
    </message>
    <message>
        <location filename="retext.py" line="361"/>
        <source>Show</source>
        <translation>Anzeigen</translation>
    </message>
    <message>
        <location filename="retext.py" line="362"/>
        <source>Next</source>
        <translation>Weiter</translation>
    </message>
    <message>
        <location filename="retext.py" line="363"/>
        <source>Previous</source>
        <translation>Zurück</translation>
    </message>
    <message>
        <location filename="retext.py" line="365"/>
        <source>Get help online</source>
        <translation>Online Hilfe bekommen</translation>
    </message>
    <message>
        <location filename="retext.py" line="370"/>
        <source>About %s</source>
        <translation>Über %s</translation>
    </message>
    <message>
        <location filename="retext.py" line="373"/>
        <source>About Qt</source>
        <translation>Über Qt</translation>
    </message>
    <message>
        <location filename="retext.py" line="394"/>
        <source>Bold</source>
        <translation>Fett</translation>
    </message>
    <message>
        <location filename="retext.py" line="395"/>
        <source>Italic</source>
        <translation>Kursiv</translation>
    </message>
    <message>
        <location filename="retext.py" line="396"/>
        <source>Underline</source>
        <translation>Unterstrichen</translation>
    </message>
    <message>
        <location filename="retext.py" line="399"/>
        <source>Save to Google Docs</source>
        <translation>In Google Docs speichern</translation>
    </message>
    <message>
        <location filename="retext.py" line="406"/>
        <source>Tags</source>
        <translation>Stichworte</translation>
    </message>
    <message>
        <location filename="retext.py" line="410"/>
        <source>Symbols</source>
        <translation>Symbole</translation>
    </message>
    <message>
        <location filename="retext.py" line="433"/>
        <source>File</source>
        <translation>Datei</translation>
    </message>
    <message>
        <location filename="retext.py" line="434"/>
        <source>Edit</source>
        <translation>Bearbeiten</translation>
    </message>
    <message>
        <location filename="retext.py" line="435"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <location filename="retext.py" line="438"/>
        <source>Open recent</source>
        <translation>Zuletzt geöffnet</translation>
    </message>
    <message>
        <location filename="retext.py" line="441"/>
        <source>Directory</source>
        <translation>Verzeichnis</translation>
    </message>
    <message>
        <location filename="retext.py" line="449"/>
        <source>Export</source>
        <translation>Exportieren</translation>
    </message>
    <message>
        <location filename="retext.py" line="474"/>
        <source>Spell check</source>
        <translation>Rechtschreibprüfung</translation>
    </message>
    <message>
        <location filename="retext.py" line="482"/>
        <source>Default editing mode</source>
        <translation>Standard-Bearbeitungsmodus</translation>
    </message>
    <message>
        <location filename="retext.py" line="485"/>
        <source>Formatting</source>
        <translation>Formatieren</translation>
    </message>
    <message>
        <location filename="retext.py" line="523"/>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <location filename="retext.py" line="526"/>
        <source>Case sensitively</source>
        <translation>Groß-/Kleinschreibung</translation>
    </message>
    <message>
        <location filename="retext.py" line="1421"/>
        <source>New document</source>
        <translation>Neues Dokument</translation>
    </message>
    <message>
        <location filename="retext.py" line="563"/>
        <source>You have neither Markdown nor Docutils modules installed!</source>
        <translation>Es sind weder Markdown- noch Docutils-Module installiert!</translation>
    </message>
    <message>
        <location filename="retext.py" line="819"/>
        <source>Enter locale name (example: en_US)</source>
        <translation>Spracheinstellung eingeben (zum Beispiel: de_DE)</translation>
    </message>
    <message>
        <location filename="retext.py" line="916"/>
        <source>Please, save the file somewhere.</source>
        <translation>Bitte die Datei irgendwo speichern.</translation>
    </message>
    <message>
        <location filename="retext.py" line="903"/>
        <source>Webpages saved in &lt;code&gt;html&lt;/code&gt; directory.</source>
        <translation>Webseiten gespeichert im Verzeichnis &lt;code&gt;html&lt;/code&gt;.</translation>
    </message>
    <message>
        <location filename="retext.py" line="905"/>
        <source>Show directory</source>
        <translation>Verzeichnis anzeigen</translation>
    </message>
    <message>
        <location filename="retext.py" line="910"/>
        <source>Webpages generator is not installed!</source>
        <translation>Webseiten-Generator ist nicht installiert!</translation>
    </message>
    <message>
        <location filename="retext.py" line="1032"/>
        <source>Select one or several files to open</source>
        <translation>Ein oder mehrere Dateien zum Öffnen auswählen</translation>
    </message>
    <message>
        <location filename="retext.py" line="1032"/>
        <source>Supported files</source>
        <translation>Unterstützte Dateien</translation>
    </message>
    <message>
        <location filename="retext.py" line="1032"/>
        <source>All files (*)</source>
        <translation>Alle Dateien (*)</translation>
    </message>
    <message>
        <location filename="retext.py" line="1091"/>
        <source>Plain text (*.txt)</source>
        <translation>Klartext (*.txt)</translation>
    </message>
    <message>
        <location filename="retext.py" line="1094"/>
        <source>ReStructuredText files</source>
        <translation>ReStructuredText-Dateien</translation>
    </message>
    <message>
        <location filename="retext.py" line="1097"/>
        <source>Markdown files</source>
        <translation>Markdown-Dateien</translation>
    </message>
    <message>
        <location filename="retext.py" line="1174"/>
        <source>Save file</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="retext.py" line="1112"/>
        <source>Cannot save to file because it is read-only!</source>
        <translation>Kann nicht speichern, Datei ist schreibgeschützt.</translation>
    </message>
    <message>
        <location filename="retext.py" line="1165"/>
        <source>Export document to ODT</source>
        <translation>Dokument in ODT exportieren</translation>
    </message>
    <message>
        <location filename="retext.py" line="1165"/>
        <source>OpenDocument text files (*.odt)</source>
        <translation>OpenDocument-Dateien (*.odt)</translation>
    </message>
    <message>
        <location filename="retext.py" line="1174"/>
        <source>HTML files (*.html *.htm)</source>
        <translation>HTML-Dateien  (*.html, *.htm)</translation>
    </message>
    <message>
        <location filename="retext.py" line="1197"/>
        <source>Export document to PDF</source>
        <translation>Dokument in PDF exportieren</translation>
    </message>
    <message>
        <location filename="retext.py" line="1197"/>
        <source>PDF files (*.pdf)</source>
        <translation>PDF-Dateien (*.pdf)</translation>
    </message>
    <message>
        <location filename="retext.py" line="1212"/>
        <source>Print document</source>
        <translation>Dokument drucken</translation>
    </message>
    <message>
        <location filename="retext.py" line="1231"/>
        <source>Export document</source>
        <translation>Dokument exportieren</translation>
    </message>
    <message>
        <location filename="retext.py" line="1255"/>
        <source>Failed to execute the command:</source>
        <translation>Ausführung des Befehls fehlgeschlagen:</translation>
    </message>
    <message>
        <location filename="retext.py" line="1316"/>
        <source>Incorrect user name or password!</source>
        <translation>Benutzername oder Passwort fehlerhaft!</translation>
    </message>
    <message>
        <location filename="retext.py" line="1319"/>
        <source>Authentification failed, please check your internet connection!</source>
        <translation>Authentifikation fehlgeschlagen, bitte Internetverbindung überprüfen!</translation>
    </message>
    <message>
        <location filename="retext.py" line="1395"/>
        <source>The document has been modified.
Do you want to save your changes?</source>
        <translation>Das Dokument wurde verändert.⏎
Sollen die Änderungen gespeichert werden?</translation>
    </message>
    <message>
        <location filename="retext.py" line="1428"/>
        <source>HTML code</source>
        <translation>HTML-Code</translation>
    </message>
    <message>
        <location filename="retext.py" line="1437"/>
        <source>Simple but powerful editor for Markdown and ReStructuredText</source>
        <translation>Einfacher aber mächtiger Editor für Markdown and ReStructuredText</translation>
    </message>
    <message>
        <location filename="retext.py" line="1437"/>
        <source>Author: Dmitry Shachnev, 2011</source>
        <translation>Autor: Dmitry Shachnev, 2011</translation>
    </message>
    <message>
        <location filename="retext.py" line="1437"/>
        <source>Website</source>
        <translation>Webseite</translation>
    </message>
    <message>
        <location filename="retext.py" line="1437"/>
        <source>Markdown syntax</source>
        <translation>Markdown-Syntax</translation>
    </message>
    <message>
        <location filename="retext.py" line="1437"/>
        <source>ReST syntax</source>
        <translation>ReST-Syntax</translation>
    </message>
    <message>
        <location filename="retext.py" line="1488"/>
        <source>Could not parse file contents, check if you have the necessary module installed!</source>
        <translation>Dateiinhalt konnte nicht geparst werden. Überprüfen Sie, ob die notwendigen Module installiert sind!</translation>
    </message>
</context>
</TS>
